#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['sqimple']

package_data = \
{'': ['*'], 'sqimple': ['static/*', 'templates/*']}

entry_points = \
{'console_scripts': ['sqimple = sqimple.server:main']}

setup(name='sqimple',
      version='0.0.2',
      description='Simple SQLite Web Interface',
      author='Zach Gulde',
      author_email='zachgulde@gmail.com',
      url=None,
      packages=packages,
      package_data=package_data,
      entry_points=entry_points,
     )
